/* purpleview.h */

#define PVVERSION_A "1.3.2"
#define PVVERSION _T(PVVERSION_A)

#define PVCOPYRIGHT_YEAR _T("2010")

#ifdef UNICODE
#define PVSYMBOL_COPYRIGHT _T("\xa9")
#else
#define PVSYMBOL_COPYRIGHT _T("(c)")
#endif

struct iinfo_struct {
	int img_source;     // 0 = file;   1 = clipboard
	TCHAR *img_filename;

	
	LPBITMAPINFOHEADER lpdib; // used only when saving / loading
	unsigned int lpdib_size;  // used only when saving / loading
	unsigned int lpdib_bits_offs;  // used when saving; optional when loading

	unsigned int file_size;  // for display purposes only

	// Count of number of bits used for each color
	// (for display purposes only)
	unsigned char bits_red, bits_green, bits_blue, bits_gray;
	unsigned char bits_reserved1, bits_reserved2, bits_reserved3, bits_alpha;
	//
	int bitsperpixel;
	int interlaced;
	int palettecolors;
	int colortype;
	int res_flag;     // 0 = no information; 1 = meters; 2 = unknown units
	int res_x, res_y;
	int compression;
	int img_fmt;
	int has_bgcolor;
	COLORREF bgcolor;

	int src_width, src_height;
	int adj_src_width, adj_src_height;
	double adj_src_width_flt, adj_src_height_flt;
};

// environment info
// Includes any information that might be needed by the various
// image read/write functions.
struct einfo_struct {
	HANDLE heap;  // process heap to use for allocating large memory blocks
	COLORREF custom_bg;
	int use_image_bg, use_custom_bg;
	int use_gamma;

	TCHAR *software_name;
	// This string is often needed by libraries or file formats that don't use
	// Unicode, so it may be worth it to have both Unicode and ANSI versions.
	TCHAR *software_name_full;
	char *software_name_full_a;

	double monitor_gamma;
	int bmp_alpha32;
};


#define MSG_S 1 // severe
#define MSG_E 0 // error
#define MSG_W 2 // warning
#define MSG_I 3 // information

#define COLORTYPE_GRAY      0
#define COLORTYPE_RGB       2
#define COLORTYPE_PALETTE   3
#define COLORTYPE_GA        4
#define COLORTYPE_RGBA      6

#define COLORTYPE_UNKNOWN   8

#define COLORTYPE_YCbCr     9
#define COLORTYPE_CMYK      10
#define COLORTYPE_YCCK      11


#define COMPR_NONE    0
#define COMPR_RLE8    1
#define COMPR_RLE4    2
#define COMPR_DEFLATE 5
#define COMPR_JPEG    7
#define COMPR_LZW     8
#define COMPR_UNKNOWN 9

#define FMT_PNG       1
#define FMT_BMP       2
//#define FMT_BMP_OLD   3
#define FMT_JPEG      4
#define FMT_TIFF      5
#define FMT_GIF       6


void pv_mesg(HWND hwnd,int severity, const TCHAR *fmt, ...);
int pv_save_as_dialog(HWND hwnd,const TCHAR *title,TCHAR *filename,
					const TCHAR *filter,const TCHAR *defext);
int pv_get_dib_bytes_per_row(int bpp, int width);


int pv_png_open(HWND hwnd, struct iinfo_struct *iinfo, struct einfo_struct *einfo);
int pv_png_save(HWND hwnd, struct iinfo_struct *iinfo, struct einfo_struct *einfo);
int pv_png_get_copyright(TCHAR *buf, int buflen);

int pv_bmp_open(HWND hwnd, struct iinfo_struct *iinfo, struct einfo_struct *einfo);
int pv_bmp_save(HWND hwnd, struct iinfo_struct *iinfo, struct einfo_struct *einfo);

int pv_tiff_save(HWND hwnd, struct iinfo_struct *iinfo, struct einfo_struct *einfo);

int pv_jpeg_open(HWND hwnd,struct iinfo_struct *iinfo, struct einfo_struct *einfo);
int pv_jpeg_get_copyright(TCHAR *buf, int buflen);
